@@ -171,7 +171,7 @@ QueryParser::parse_query(const string &query_string, unsigned flags,
 
     Query result = internal->parse_query(query_string, flags, default_prefix);
     if (internal->errmsg && strcmp(internal->errmsg, "parse error") == 0) {
-	flags &= FLAG_CJK_NGRAM;
+	flags &= FLAG_CJK_NGRAM | FLAG_NO_POSITIONS;
 	result = internal->parse_query(query_string, flags, default_prefix);
     }
 
